@@ -24,9 +24,13 @@ from uv_secure.configuration import (
     override_config,
 )
 from uv_secure.directory_scanner import get_dependency_file_to_config_map
+from uv_secure.directory_scanner.directory_scanner import (
+    get_dependency_files_to_config_map,
+)
 from uv_secure.package_info import (
     download_packages,
     PackageInfo,
+    parse_pylock_toml_file,
     parse_requirements_txt_file,
     parse_uv_lock_file,
 )
@@ -64,7 +68,7 @@ def _render_vulnerability_table(
                 if vuln.link
                 else Text(vuln.id)
             )
-            renderables = [
+            renderables: list[Text] = [
                 Text.assemble(
                     (
                         package.info.name,
@@ -119,7 +123,7 @@ def _render_vulnerability_table(
                     Text(", ").join(alias_links) if alias_links else Text("")
                 )
             if config.vulnerability_criteria.desc:
-                renderables.append(vuln.details)
+                renderables.append(Text(vuln.details))
             table.add_row(*renderables)
     return table
 
@@ -140,7 +144,7 @@ def _render_issue_table(
     table.add_column("Yanked Reason", min_width=20, max_width=24)
     table.add_column("Age", min_width=20, max_width=24)
     for package in maintenance_issue_packages:
-        renderables = [
+        renderables: list[Text] = [
             Text.assemble(
                 (
                     package.info.name,
@@ -154,11 +158,13 @@ def _render_issue_table(
                     f"{package.info.version}/",
                 )
             ),
-            str(package.info.yanked),
-            package.info.yanked_reason if package.info.yanked_reason else "Unknown",
-            humanize.precisedelta(package.age, minimum_unit="days")
+            Text(str(package.info.yanked)),
+            Text(package.info.yanked_reason)
+            if package.info.yanked_reason
+            else Text("Unknown"),
+            Text(humanize.precisedelta(package.age, minimum_unit="days"))
             if package.age
-            else "Unknown",
+            else Text("Unknown"),
         ]
         table.add_row(*renderables)
     return table
@@ -186,7 +192,7 @@ async def check_dependencies(
     """Checks dependencies for vulnerabilities and summarizes the results
 
     Args:
-        dependency_file_path: uv.lock file or requirements.txt file path
+        dependency_file_path: PEP751 pylock.toml, requirements.txt, or uv.lock file path
         config: uv-secure configuration object
         http_client: HTTP client for making requests
         disable_cache: flag whether to disable cache for HTTP requests
@@ -194,25 +200,39 @@ async def check_dependencies(
     Returns:
         tuple with status code and output for console to render
     """
-    console_outputs = []
+    console_outputs: list[ConsoleRenderable] = []
 
     if not await dependency_file_path.exists():
         console_outputs.append(
-            f"[bold red]Error:[/] File {dependency_file_path} does not exist."
+            Text.from_markup(
+                f"[bold red]Error:[/] File {dependency_file_path} does not exist."
+            )
         )
         return 3, console_outputs
 
-    if dependency_file_path.name == "uv.lock":
-        dependencies = await parse_uv_lock_file(dependency_file_path)
-    else:  # Assume dependency_file_path.name == "requirements.txt"
-        dependencies = await parse_requirements_txt_file(dependency_file_path)
+    try:
+        if dependency_file_path.name == "uv.lock":
+            dependencies = await parse_uv_lock_file(dependency_file_path)
+        elif dependency_file_path.name == "requirements.txt":
+            dependencies = await parse_requirements_txt_file(dependency_file_path)
+        else:  # Assume dependency_file_path.name == "pyproject.toml"
+            dependencies = await parse_pylock_toml_file(dependency_file_path)
+    except Exception as e:
+        console_outputs.append(
+            Text.from_markup(
+                f"[bold red]Error:[/] Failed to parse {dependency_file_path}: {e}"
+            )
+        )
+        return 3, console_outputs
 
     if len(dependencies) == 0:
         return 0, console_outputs
 
     console_outputs.append(
-        f"[bold cyan]Checking {dependency_file_path} dependencies for vulnerabilities"
-        "...[/]\n"
+        Text.from_markup(
+            f"[bold cyan]Checking {dependency_file_path} dependencies for "
+            "vulnerabilities ...[/]\n"
+        )
     )
 
     packages = await download_packages(dependencies, http_client, disable_cache)
@@ -229,10 +249,28 @@ async def check_dependencies(
             for name, specifiers in config.ignore_packages.items()
         }
 
+    has_none_direct_dependency = any(
+        isinstance(package, PackageInfo) and package.direct_dependency is None
+        for package in packages
+    )
+    if has_none_direct_dependency and (
+        config.vulnerability_criteria.check_direct_dependencies_only
+        or config.maintainability_criteria.check_direct_dependencies_only
+    ):
+        console_outputs.append(
+            Text.from_markup(
+                f"[bold yellow]Warning:[/] {dependency_file_path} doesn't contain "
+                "the necessary information to determine direct dependencies."
+            )
+        )
+
     for idx, package in enumerate(packages):
         if isinstance(package, BaseException):
             console_outputs.append(
-                f"[bold red]Error:[/] {dependencies[idx]} raised exception: {package}"
+                Text.from_markup(
+                    f"[bold red]Error:[/] {dependencies[idx]} raised exception: "
+                    f"{package}"
+                )
             )
             return 3, console_outputs
 
@@ -242,13 +280,15 @@ async def check_dependencies(
                 specifier.contains(package.info.version) for specifier in specifiers
             ):
                 console_outputs.append(
-                    f"[bold yellow]Skipping {package.info.name} "
-                    f"({package.info.version}) as it is ignored[/]"
+                    Text.from_markup(
+                        f"[bold yellow]Skipping {package.info.name} "
+                        f"({package.info.version}) as it is ignored[/]"
+                    )
                 )
                 continue
 
         if (
-            package.direct_dependency
+            package.direct_dependency is not False
             or not config.vulnerability_criteria.check_direct_dependencies_only
         ):
             # Filter out ignored vulnerabilities
@@ -267,7 +307,7 @@ async def check_dependencies(
                 vulnerable_packages.append(package)
 
         if (
-            package.direct_dependency
+            package.direct_dependency is not False
             or not config.maintainability_criteria.check_direct_dependencies_only
         ):
             found_rejected_yanked_package = (
@@ -345,7 +385,7 @@ async def check_lock_files(
     check_direct_dependency_maintenance_issues_only: bool | None,
     config_path: Path | None,
 ) -> RunStatus:
-    """Checks uv.lock and requirements.txt files for issues
+    """Checks PEP751 pylock.toml, requirements.txt, and uv.lock files for issues
 
     Check specified or discovered uv.lock and requirements.txt files for maintenance
     issues or known vulnerabilities
@@ -389,17 +429,17 @@ async def check_lock_files(
                 )
                 lock_to_config_map = dict.fromkeys(file_apaths, config)
             elif all(
-                file_path.name in {"requirements.txt", "uv.lock"}
+                file_path.name in {"pylock.toml", "requirements.txt", "uv.lock"}
                 for file_path in file_apaths
             ):
-                lock_to_config_map = await get_dependency_file_to_config_map(
+                lock_to_config_map = await get_dependency_files_to_config_map(
                     file_apaths
                 )
                 file_apaths = tuple(lock_to_config_map.keys())
             else:
                 console.print(
                     "[bold red]Error:[/] file_paths must either reference a single "
-                    "project root directory or a sequence of uv.lock / "
+                    "project root directory or a sequence of uv.lock / pylock.toml / "
                     "requirements.txt file paths"
                 )
                 return RunStatus.RUNTIME_ERROR
