@@ -1,5 +1,6 @@
 from uv_secure.package_info.dependency_file_parser import (
     Dependency,
+    parse_pylock_toml_file,
     parse_requirements_txt_file,
     parse_uv_lock_file,
 )
@@ -13,6 +14,7 @@ __all__ = [
     "Dependency",
     "PackageInfo",
     "download_packages",
+    "parse_pylock_toml_file",
     "parse_requirements_txt_file",
     "parse_uv_lock_file",
 ]
